@@ -22,6 +22,19 @@ test_that("SE works", {
     expect_equal(dim(attr(d, "bootstrap")), c(100, 2))
 })
 
+test_that("names of columns", {
+    m0 <- matrix_to_long(matrix(c(100, 60, 40, 0, 0, 40, 60, 100), ncol = 2),
+                         group = "race", unit = "tract")
+
+    d <- dissimilarity(m0, "race", "tract", weight = "n")
+    expect_equal(dim(d), c(1, 2))
+
+    data.table::setDT(m0)
+    d <- dissimilarity(m0, "race", "tract", weight = "n")
+    expect_equal(dim(d), c(1, 2))
+})
+
+
 test_that("bootstrapping fails when sample size is non-integer", {
     m0 <- matrix_to_long(matrix(c(100.3, 60, 40, 0, 0, 40, 60, 100), ncol = 2))
     expect_error(dissimilarity(m0, "group", "unit", weight = "n", se = TRUE))
